netapp_ontap.models.switch_port_remote_port_device_dcn API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.switch_port_remote_port_device_dcn`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SwitchPortRemotePortDeviceDcnSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SwitchPortRemotePortDeviceDcn object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the switch_port_remote_port_device_dcn.

  `name: str GET POST PATCH`

    Compute node name.

    Example: node1

  `serial_number: str GET POST PATCH`

    Compute node serial number.

    Example: 4048820-60-9

  `uuid: str GET POST PATCH`

    Compute node UUID.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412